@@ -214,15 +214,19 @@ const setupEvents = () => {
     };
     const setIcon = (value) => {
         document.getElementById('icon-path').value = value;
-        iconLocationChange({ target: document.getElementById('icon-path') });
+        document.getElementById('icon-path').dispatchEvent(new Event('input'));
     };
-    
     configurationSetters['filenames'] = setEntryScript;
     configurationSetters['onefile'] = setOnefile;
     configurationSetters['console'] = setConsole;
     configurationSetters['datas'] = setAdditionalFile;
     configurationSetters['icon_file'] = setIcon;
 
+    configurationCleaners.push(() => setEntryScript('')); // filenames
+    configurationCleaners.push(() => setOnefile(false)); // onefile
+    configurationCleaners.push(() => setConsole(false)); // console
+    configurationCleaners.push(() => setIcon('')); // icon_file
+
     // Soft initialise (to trigger any required initial events)
     setEntryScript('');
     setOnefile(false);
